@@ -69,10 +69,11 @@ function ( x, y, main=deparse( substitute( y ) ), gray.scale = FALSE, ...) {
   vrb.obs <- .factor2num( y )
   vrb.imp <- .factor2num( imputed( x, y ) )
   mi.hist(  x, y, xlab = main, main = main, gray.scale = gray.scale ) 
-  binnedplot( fit[  !is.na( y ) ], res[  !is.na( y ) ], nclass = sqrt( length( fit[ !is.na( y ) ] ) ), main = main )
-  mtext( "Binned Residual", 3, cex = 0.7, adj = NA ) 
+#  binnedplot( fit[  !is.na( y ) ], res[  !is.na( y ) ], nclass = sqrt( length( fit[ !is.na( y ) ] ) ), main = main )
+#  mtext( "Binned Residual", 3, cex = 0.7, adj = NA ) 
   mi.scatterplot( vrb.obs, vrb.imp, fit, xlab = "predicted", ylab = main, main = main, gray.scale = gray.scale )
   plot( 0, 0, type = "n", xaxt = "n", yaxt = "n", xlab = "", ylab = "", frame.plot = FALSE )
+  plot( 0, 0, type = "n", xaxt = "n", yaxt = "n", xlab = "", ylab = "", frame.plot = FALSE )
 } 
 )
 
@@ -89,10 +90,11 @@ function ( x, y, main=deparse( substitute( y ) ), gray.scale = FALSE, ...) {
   vrb.imp <- as.numeric(imputed(x, y))
   vrb.obs <- as.numeric(y)
   mi.hist(  x, y, type = vrb.typ, xlab = main, main = main, gray.scale = gray.scale )
-  binnedplot( fit[ !is.na(y) ], res[!is.na(y)], nclass = sqrt( length( fit[ !is.na(y)] ) ), main = main)
-  mtext( "Binned Residual", 3, cex = 0.7, adj = NA ) 
+#  binnedplot( fit[ !is.na(y) ], res[!is.na(y)], nclass = sqrt( length( fit[ !is.na(y)] ) ), main = main)
+#  mtext( "Binned Residual", 3, cex = 0.7, adj = NA ) 
   mi.scatterplot( Yobs=vrb.obs, vrb.imp, fit, xlab = "predicted", ylab = main, main = main, gray.scale = gray.scale )
   plot( 0, 0, type = "n", xaxt = "n", yaxt = "n", xlab = "", ylab = "", frame.plot = FALSE )
+  plot( 0, 0, type = "n", xaxt = "n", yaxt = "n", xlab = "", ylab = "", frame.plot = FALSE )
 } 
 )
 
